@@ -26,22 +26,23 @@
  * exception statement from your version.
  */
 
-#ifndef PREVIEWLISTDELEGATE_H
-#define PREVIEWLISTDELEGATE_H
+#pragma once
 
 #include <QItemDelegate>
 
+#include "progressbarpainter.h"
+
 class PreviewListDelegate final : public QItemDelegate
 {
     Q_OBJECT
-    Q_DISABLE_COPY(PreviewListDelegate)
+    Q_DISABLE_COPY_MOVE(PreviewListDelegate)
 
 public:
     explicit PreviewListDelegate(QObject *parent = nullptr);
 
-private:
     void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
     QWidget *createEditor(QWidget *, const QStyleOptionViewItem &, const QModelIndex &) const override;
-};
 
-#endif // PREVIEWLISTDELEGATE_H
+private:
+    ProgressBarPainter m_progressBarPainter;
+};
